/* tifs.h
 * TiFS defines
 * (C) 1996 David Given
 */

#include <asm/types.h>

#ifndef __KERNEL__
typedef __u8 u8;
typedef __u16 u16;
typedef __u32 u32;
#endif

#define TIFS_EMPTY	0	/* Empty entry */
#define TIFS_FILE	1	/* Is a file */
#define TIFS_LINK	2	/* Is a symlink */
#define TIFS_DIR	3	/* Is a directory */
#define TIFS_CHRDEV	4	/* Is a character device */
#define TIFS_BLKDEV	5	/* Is a block device */
#define TIFS_FIFO	6	/* Is a FIFO */
#define TIFS_SOCKET	7	/* Is a named socket */

#define TIFS_NAMELENGTH	16	/* Maximum name length */
#define TIFS_ROOT_INO	1	/* Where the root directory lives */

typedef struct tifs_fileinfo_s {
	u8  filename[TIFS_NAMELENGTH+1];	/* Filename */
	u8  filetype;				/* File type */
	u16 dirid;				/* dirid */
	u16 start;				/* Start block */
	u16 blocks;				/* Number of blocks */

	u16 mode;				/* Straight out of Minix V2 */
	u16 uid;
	u16 gid;
	u32 size;
	u32 atime;
	u32 mtime;
	u32 ctime;
} TIFS_Fileinfo;

typedef struct tifs_superblock_s {
	u8  magic[4];		/* = "TiFS" */

	u16 blocksize;		/* Size of a block */
	u16 discsize;		/* Size of disc in blocks */
	u16 firstusable;	/* First usable block (bottom of disc) */
	u16 boot_start;		/* Start block of boot image */
	u16 boot_size;		/* Size of boot image */
	u16 numentries;		/* Number of entries in directory */
	u16 numfilesused;	/* Number of entries *used* in directory */
	u16 numblocksused;	/* Number of blocks *used* on disc */

	TIFS_Fileinfo file[0];	/* The directory itself. Entry 0 is unused */
} TIFS_Superblock;

